***************
Release history
***************

.. Changelog entries should follow this format:

   version (release date)
   ======================

   **section**

   - One-line description of change (link to Github issue/PR)

.. Changes should be organized in one of several sections:

   - Added
   - Changed
   - Deprecated
   - Removed
   - Fixed

0.3.0 (NOvember 6, 2020)
========================

The version of this package as it existed prior to 0.3.0 has been renamed
to ``keras-lmu``. This package will continue as a metapackage for installing
multiple LMU implementations.
